==> scout-browser-4.42.1.tar.gz: scout-browser-4.42.1/tests/adapter/mongo/test_case_events.py <==
def test_case_dismissed_variants(adapter, institute_obj, case_obj, user_obj, variant_obj):
    """Test adaptter function that retrieves the list of dismissed variant ids for a case"""
    # GIVEN a variant db with at least one variant, and no events
    adapter.case_collection.insert_one(case_obj)
    adapter.institute_collection.insert_one(institute_obj)
    adapter.user_collection.insert_one(user_obj)
    adapter.variant_collection.insert_one(variant_obj)

    # WHEN dismissing a variant
    link = "/".join([institute_obj["_id"], case_obj["_id"], variant_obj["_id"]])
    dismiss_reason = [3, 5, 7]
    updated_variant = adapter.update_dismiss_variant(
        institute=institute_obj,
        case=case_obj,
        user=user_obj,
        link=link,
        variant=variant_obj,
        dismiss_variant=dismiss_reason,
    )
    # THEN one event should be found in events collection
    assert sum(1 for i in adapter.event_collection.find()) == 1
    # AND case_dismissed_variants should return a list containing the id of the variant
    assert adapter.case_dismissed_variants(institute_obj, case_obj) == [variant_obj["_id"]]

    # IF the variant dismissed status is reset
    updated_variant = adapter.update_dismiss_variant(
        institute=institute_obj,
        case=case_obj,
        user=user_obj,
        link=link,
        variant=updated_variant,
        dismiss_variant=[],  # with this list empty the status is reset to not dismissed
    )
    # THEN two events should be found in events collection
    assert sum(1 for i in adapter.event_collection.find()) == 2
    # AND case_dismissed_variants should NOT return a list containing the id of the variant
    assert adapter.case_dismissed_variants(institute_obj, case_obj) == []

    # AND THEN the variant is dismissed again
    updated_variant = adapter.update_dismiss_variant(
        institute=institute_obj,
        case=case_obj,
        user=user_obj,
        link=link,
        variant=updated_variant,
        dismiss_variant=dismiss_reason,
    )
    # THEN three events should be found in events collection
    assert sum(1 for i in adapter.event_collection.find()) == 3
    # AND case_dismissed_variants should again return a list containing the id of the variant
    assert adapter.case_dismissed_variants(institute_obj, case_obj) == [variant_obj["_id"]]

==> scout-browser-4.66.tar.gz: scout-browser-4.66/tests/adapter/mongo/test_case_events.py <==
def test_diagnose(adapter, institute_obj, case_obj, user_obj, omim_term):
    """Test update a case onject with a diagnosis"""

    # Given a database with no events
    assert adapter.event_collection.find_one() is None

    # GIVEN a test case with no assigned diagnosis
    assert case_obj.get("diagnosis_phenotypes") is None
    adapter.case_collection.insert_one(case_obj)

    # WHEN case is diagnosis is updated via the "diagnose" function
    updated_case = adapter.diagnose(
        institute_obj,
        case_obj,
        user_obj,
        "test_link",
        omim_term,
        ["ind1_id|ind1_name", "ind2_id|ind2_name"],
        False,
    )

    # THEN case should be updated with diagnosis data
    assert updated_case["diagnosis_phenotypes"][0]["disease_id"] == omim_term["disease_id"]
    assert updated_case["diagnosis_phenotypes"][0]["disease_nr"]
    assert updated_case["diagnosis_phenotypes"][0]["description"]
    assert updated_case["diagnosis_phenotypes"][0]["individuals"]

    # And a relative event should have been created in database
    assert adapter.event_collection.find_one()


def test_case_dismissed_variants(adapter, institute_obj, case_obj, user_obj, variant_obj):
    """Test adaptter function that retrieves the list of dismissed variant ids for a case"""
    # GIVEN a variant db with at least one variant, and no events
    adapter.case_collection.insert_one(case_obj)
    adapter.institute_collection.insert_one(institute_obj)
    adapter.user_collection.insert_one(user_obj)
    adapter.variant_collection.insert_one(variant_obj)

    # WHEN dismissing a variant
    link = "/".join([institute_obj["_id"], case_obj["_id"], variant_obj["_id"]])
    dismiss_reason = [3, 5, 7]
    updated_variant = adapter.update_dismiss_variant(
        institute=institute_obj,
        case=case_obj,
        user=user_obj,
        link=link,
        variant=variant_obj,
        dismiss_variant=dismiss_reason,
    )
    # THEN one event should be found in events collection
    assert sum(1 for i in adapter.event_collection.find()) == 1
    # AND case_dismissed_variants should return a list containing the id of the variant
    assert adapter.case_dismissed_variants(institute_obj, case_obj) == [variant_obj["_id"]]

    # IF the variant dismissed status is reset
    updated_variant = adapter.update_dismiss_variant(
        institute=institute_obj,
        case=case_obj,
        user=user_obj,
        link=link,
        variant=updated_variant,
        dismiss_variant=[],  # with this list empty the status is reset to not dismissed
    )
    # THEN two events should be found in events collection
    assert sum(1 for i in adapter.event_collection.find()) == 2
    # AND case_dismissed_variants should NOT return a list containing the id of the variant
    assert adapter.case_dismissed_variants(institute_obj, case_obj) == []

    # AND THEN the variant is dismissed again
    updated_variant = adapter.update_dismiss_variant(
        institute=institute_obj,
        case=case_obj,
        user=user_obj,
        link=link,
        variant=updated_variant,
        dismiss_variant=dismiss_reason,
    )
    # THEN three events should be found in events collection
    assert sum(1 for i in adapter.event_collection.find()) == 3
    # AND case_dismissed_variants should again return a list containing the id of the variant
    assert adapter.case_dismissed_variants(institute_obj, case_obj) == [variant_obj["_id"]]
